<?php

namespace Drupal\one_time_password\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form for configuring the One Time Password module.
 */
class OneTimePasswordSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'one_time_password_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['one_time_password.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildForm($form, $form_state);
    $form['force_otp'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Force all authenticated users to enable OTP'),
      '#default_value' => $this->config('one_time_password.settings')->get('force_otp'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('one_time_password.settings')
      ->set('force_otp', $form_state->getValue('force_otp'))
      ->save();
    $this->messenger()->addStatus(t('The configuration options have been saved.'));
  }

}
