<?php

namespace Drupal\Tests\one_time_password\Functional;

use Drupal\Core\Session\AccountInterface;
use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\user\Traits\UserCreationTrait;

/**
 * Test forcing users to enable OTP.
 *
 * @group one_time_password
 */
class ForceOtpTest extends BrowserTestBase {

  use UserCreationTrait;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'one_time_password',
    'user',
    'block',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->drupalPlaceBlock('local_tasks_block');
  }

  /**
   * Test forcing users to enable OTP.
   */
  public function testForcingOtp(): void {
    $user = $this->createUser(['administer one time password settings']);
    $this->assertInstanceOf(AccountInterface::class, $user);
    $this->drupalLogin($user);

    $this->drupalGet('/admin/config/people/one_time_password/settings');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('Force all authenticated users to enable OTP');

    // Enable force OTP setting.
    $this->submitForm(['force_otp' => 1], 'Save configuration');
    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    $this->drupalGet('/user');
    $this->assertSession()->pageTextContains('You must enable two factor authentication to continue.');
    $this->submitForm([], 'Enable Two-Factor Authentication');
    $this->assertSession()->pageTextContains('Two-factor authentication has been enabled. See the instructions below for setting up your one time password.');

    $this->drupalGet('/user');
  }

}
